@@ -836,6 +836,8 @@ class Matcher(
 ):
     '''Represents a matcher that can perform special data matching capabilities between a given pattern and a target.
 
+    :exampleMetadata: infused
+
     Example::
 
         # Given a template -
@@ -935,7 +937,7 @@ class Template(metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/assertions.Template"
     Typically used, as part of unit tests, to validate that the rendered
     CloudFormation template has expected resources and properties.
 
-    :exampleMetadata: nofixture
+    :exampleMetadata: nofixture infused
 
     Example::
 
@@ -1097,6 +1099,8 @@ class Capture(
     Using an instance of this class within a Matcher will capture the matching value.
     The ``as*()`` APIs on the instance can be used to get the captured value.
 
+    :exampleMetadata: infused
+
     Example::
 
         # Given a template -
